# coding: utf-8

# flake8: noqa

"""
    shado-python-client

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import apis into sdk package and rename them
from shado_client.api.account_api import AccountApi as AccountApiConstructor
from shado_client.api.group_api import GroupApi as GroupApiConstructor
from shado_client.api.invitation_api import InvitationApi as InvitationApiConstructor
from shado_client.api.item_api import ItemApi as ItemApiConstructor
from shado_client.api.membership_api import MembershipApi as MembershipApiConstructor
from shado_client.api.plugin_api import PluginApi as PluginApiConstructor
from shado_client.api.plugin_instance_api import PluginInstanceApi as PluginInstanceApiConstructor
from shado_client.api.result_api import ResultApi as ResultApiConstructor
from shado_client.api.sharing_api import SharingApi as SharingApiConstructor

# import ApiClient
from shado_client.api_client import ApiClient
from shado_client.configuration import Configuration
# import models into sdk package
from shado_client.models.account import Account
from shado_client.models.group import Group
from shado_client.models.inline_response_200 import InlineResponse200
from shado_client.models.inline_response_200_1 import InlineResponse2001
from shado_client.models.inline_response_200_2 import InlineResponse2002
from shado_client.models.inline_response_200_3 import InlineResponse2003
from shado_client.models.invitation import Invitation
from shado_client.models.item import Item
from shado_client.models.membership import Membership
from shado_client.models.object_id import ObjectID
from shado_client.models.plugin import Plugin
from shado_client.models.plugin_instance import PluginInstance
from shado_client.models.result import Result
from shado_client.models.sharing import Sharing
from shado_client.models.x_any import XAny

# define the main api client
main_api_client = ApiClient()

# create and export the api object for each class
account_api = AccountApiConstructor(main_api_client)
group_api = GroupApiConstructor(main_api_client)
invitation_api = InvitationApiConstructor(main_api_client)
item_api = ItemApiConstructor(main_api_client)
membership_api = MembershipApiConstructor(main_api_client)
plugin_api = PluginApiConstructor(main_api_client)
pluginInstance_api = PluginInstanceApiConstructor(main_api_client)
result_api = ResultApiConstructor(main_api_client)
sharing_api = SharingApiConstructor(main_api_client)