# coding: utf-8

"""
    SHADO client for REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


#from setuptools import setup, find_packages  # noqa: H301
from distutils.core import setup


# NAME = "swagger-client"
NAME = "shado_client"
VERSION = "0.0.2"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name=NAME,
    version=VERSION,
    packages=["shado_client"],
    description="shado",
    author_email="",
    #url="",
    keywords=["shado", "rest", "api"],
    install_requires=REQUIRES,
    #packages=find_packages(),
    include_package_data=True,
    long_description="""\
    REST API client for the SHADO platform (generated using Swagger Codegen)
    """
)
